pub struct EnumValue(/* private fields */);Expand description
Representation of a single enum value of an EnumClass.
A structure which contains a single enum value, its name, and its
nickname.
Implementations