pub fn interval_stream_ns_with_priority(
priority: Priority,
value: u64,
) -> Pin<Box<dyn Stream<Item = ()> + Send + 'static>>Available on crate feature
v2_90 only.Expand description
Create a Stream that will provide a value every given number of nanoseconds.
The Stream must be spawned on an Executor backed by a glib::MainContext.