markup_escape_text

Function markup_escape_text 

pub fn markup_escape_text(text: &str) -> GString
#x1f; for all control sequences except for tabstop, newline and carriage return. The character references in this range are not valid XML 1.0, but they are valid XML 1.1 and will be accepted by the GMarkup parser.

text

some valid UTF-8 text

length

length of @text in bytes, or -1 if the text is nul-terminated

Returns

a newly allocated string with the escaped text