timeout_future_ns

Function timeout_future_ns 

pub fn timeout_future_ns(
    value: u64,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'static>>
Available on crate feature v2_90 only.
Create a Future that will resolve after the given number of nanoseconds.

The Future must be spawned on an Executor backed by a glib::MainContext.