pub fn timeout_future_ns_with_priority(
priority: Priority,
value: u64,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'static>>Available on crate feature
v2_90 only.Expand description
Create a Future that will resolve after the given number of nanoseconds.
The Future must be spawned on an Executor backed by a glib::MainContext.