Struct glib::object::InitiallyUnownedClass
source · [−]#[repr(C)]pub struct InitiallyUnownedClass(_);Trait Implementations
sourceimpl Deref for InitiallyUnownedClass
impl Deref for InitiallyUnownedClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for InitiallyUnownedClass
impl DerefMut for InitiallyUnownedClass
sourceimpl IsClassFor for InitiallyUnownedClass
impl IsClassFor for InitiallyUnownedClass
type Instance = InitiallyUnowned
type Instance = InitiallyUnowned
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U: IsClassFor>(&self) -> &Uwhere
Self::Instance: IsA<U::Instance>,
U::Instance: ObjectType,
fn upcast_ref<U: IsClassFor>(&self) -> &Uwhere
Self::Instance: IsA<U::Instance>,
U::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U: IsClassFor>(&mut self) -> &mut Uwhere
Self::Instance: IsA<U::Instance>,
U::Instance: ObjectType,
fn upcast_ref_mut<U: IsClassFor>(&mut self) -> &mut Uwhere
Self::Instance: IsA<U::Instance>,
U::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for InitiallyUnownedClass
impl Sync for InitiallyUnownedClass