Trait glib::object::CanDowncast [−][src]
Marker trait for the statically known possibility of downcasting from Self to T.
Marker trait for the statically known possibility of downcasting from Self to T.
impl<Super: IsA<Super>, Sub: IsA<Super>> CanDowncast<Sub> for Super[src]