SignalHandlerId

Struct SignalHandlerId 

pub struct SignalHandlerId(/* private fields */);
The id of a signal that is returned by connect.

This type does not implement Clone to prevent disconnecting the same signal handler multiple times.

use glib::SignalHandlerId;
use gtk::prelude::*;
use std::cell::RefCell;

struct Button {
    widget: gtk::Button,
    clicked_handler_id: RefCell<Option<SignalHandlerId>>,
}

impl Button {
    fn new() -> Self {
        let widget = gtk::Button::new();
        let clicked_handler_id = RefCell::new(Some(widget.connect_clicked(|_button| {
            // Do something.
        })));
        Self {
            widget,
            clicked_handler_id,
        }
    }

    fn disconnect(&self) {
        if let Some(id) = self.clicked_handler_id.take() {
            self.widget.disconnect(id)
        }
    }
}

Implementations

Source

impl SignalHandlerId

pub unsafe fn as_raw(&self) -> c_ulong

Returns the internal signal handler ID.