Struct glib::BindingClass
source · [−]#[repr(C)]pub struct BindingClass(_);Trait Implementations
sourceimpl Deref for BindingClass
impl Deref for BindingClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for BindingClass
impl DerefMut for BindingClass
sourceimpl IsClassFor for BindingClass
impl IsClassFor for BindingClass
sourcefn upcast_ref<U: IsClassFor>(&self) -> &Uwhere
Self::Instance: IsA<U::Instance>,
U::Instance: ObjectType,
fn upcast_ref<U: IsClassFor>(&self) -> &Uwhere
Self::Instance: IsA<U::Instance>,
U::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U: IsClassFor>(&mut self) -> &mut Uwhere
Self::Instance: IsA<U::Instance>,
U::Instance: ObjectType,
fn upcast_ref_mut<U: IsClassFor>(&mut self) -> &mut Uwhere
Self::Instance: IsA<U::Instance>,
U::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for BindingClass
impl Sync for BindingClass