pub struct FileTest { /* private fields */ }Implementations
sourceimpl FileTest
impl FileTest
pub const IS_REGULAR: FileTest = _
pub const IS_SYMLINK: FileTest = _
pub const IS_DIR: FileTest = _
pub const IS_EXECUTABLE: FileTest = _
pub const EXISTS: FileTest = _
sourcepub fn from_bits(bits: u32) -> Option<FileTest>
pub fn from_bits(bits: u32) -> Option<FileTest>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> FileTest
pub const fn from_bits_truncate(bits: u32) -> FileTest
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> FileTest
pub const unsafe fn from_bits_unchecked(bits: u32) -> FileTest
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: FileTest) -> bool
pub const fn intersects(&self, other: FileTest) -> bool
Returns true if there are flags common to both self and other.