Struct glib::FormatSizeFlags
source · [−]pub struct FormatSizeFlags { /* private fields */ }Implementations
sourceimpl FormatSizeFlags
impl FormatSizeFlags
pub const DEFAULT: FormatSizeFlags = _
pub const LONG_FORMAT: FormatSizeFlags = _
pub const IEC_UNITS: FormatSizeFlags = _
pub const BITS: FormatSizeFlags = _
sourcepub const fn empty() -> FormatSizeFlags
pub const fn empty() -> FormatSizeFlags
Returns an empty set of flags
sourcepub const fn all() -> FormatSizeFlags
pub const fn all() -> FormatSizeFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<FormatSizeFlags>
pub fn from_bits(bits: u32) -> Option<FormatSizeFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> FormatSizeFlags
pub const fn from_bits_truncate(bits: u32) -> FormatSizeFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> FormatSizeFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> FormatSizeFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: FormatSizeFlags) -> bool
pub const fn intersects(&self, other: FormatSizeFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: FormatSizeFlags) -> bool
pub const fn contains(&self, other: FormatSizeFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: FormatSizeFlags)
pub fn insert(&mut self, other: FormatSizeFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: FormatSizeFlags)
pub fn remove(&mut self, other: FormatSizeFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: FormatSizeFlags)
pub fn toggle(&mut self, other: FormatSizeFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: FormatSizeFlags, value: bool)
pub fn set(&mut self, other: FormatSizeFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.