Struct glib::KeyFileFlags
source · [−]pub struct KeyFileFlags { /* private fields */ }Implementations
sourceimpl KeyFileFlags
impl KeyFileFlags
pub const NONE: KeyFileFlags = _
pub const KEEP_COMMENTS: KeyFileFlags = _
pub const KEEP_TRANSLATIONS: KeyFileFlags = _
sourcepub const fn empty() -> KeyFileFlags
pub const fn empty() -> KeyFileFlags
Returns an empty set of flags
sourcepub const fn all() -> KeyFileFlags
pub const fn all() -> KeyFileFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<KeyFileFlags>
pub fn from_bits(bits: u32) -> Option<KeyFileFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> KeyFileFlags
pub const fn from_bits_truncate(bits: u32) -> KeyFileFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> KeyFileFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> KeyFileFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: KeyFileFlags) -> bool
pub const fn intersects(&self, other: KeyFileFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: KeyFileFlags) -> bool
pub const fn contains(&self, other: KeyFileFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: KeyFileFlags)
pub fn insert(&mut self, other: KeyFileFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: KeyFileFlags)
pub fn remove(&mut self, other: KeyFileFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: KeyFileFlags)
pub fn toggle(&mut self, other: KeyFileFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: KeyFileFlags, value: bool)
pub fn set(&mut self, other: KeyFileFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.