Struct glib::MainContext
source · [−]pub struct MainContext(_);Implementations
sourceimpl MainContext
impl MainContext
pub fn new() -> MainContext
pub fn acquire(&self) -> bool
pub fn dispatch(&self)
pub fn is_owner(&self) -> bool
pub fn iteration(&self, may_block: bool) -> bool
pub fn pending(&self) -> bool
pub fn pop_thread_default(&self)
pub fn push_thread_default(&self)
pub fn release(&self)
pub fn wakeup(&self)
pub fn default() -> MainContext
pub fn get_thread_default() -> Option<MainContext>
pub fn ref_thread_default() -> MainContext
sourceimpl MainContext
impl MainContext
pub fn prepare(&self) -> (bool, i32)
pub fn find_source_by_id(&self, source_id: &SourceId) -> Option<Source>
sourcepub fn invoke<F>(&self, func: F)where
F: FnOnce() + Send + 'static,
pub fn invoke<F>(&self, func: F)where
F: FnOnce() + Send + 'static,
Invokes func on the main context.
sourcepub fn invoke_with_priority<F>(&self, priority: Priority, func: F)where
F: FnOnce() + Send + 'static,
pub fn invoke_with_priority<F>(&self, priority: Priority, func: F)where
F: FnOnce() + Send + 'static,
Invokes func on the main context with the given priority.
sourcepub fn invoke_local<F>(&self, func: F)where
F: FnOnce() + 'static,
pub fn invoke_local<F>(&self, func: F)where
F: FnOnce() + 'static,
Invokes func on the main context.
Different to invoke(), this does not require func to be
Send but can only be called from the thread that owns the main context.
This function panics if called from a different thread than the one that owns the main context.
sourcepub fn invoke_local_with_priority<F>(&self, priority: Priority, func: F)where
F: FnOnce() + 'static,
pub fn invoke_local_with_priority<F>(&self, priority: Priority, func: F)where
F: FnOnce() + 'static,
Invokes func on the main context with the given priority.
Different to invoke_with_priority(), this does not require func to be
Send but can only be called from the thread that owns the main context.
This function panics if called from a different thread than the one that owns the main context.
sourcepub fn with_thread_default<R, F: Sized>(&self, func: F) -> Rwhere
F: FnOnce() -> R,
pub fn with_thread_default<R, F: Sized>(&self, func: F) -> Rwhere
F: FnOnce() -> R,
Calls closure with context configured as the thread default one.
Thread default context is changed in panic-safe manner by calling
push_thread_default before calling closure
and pop_thread_default afterwards regardless
of whether closure panicked or not.
sourceimpl MainContext
impl MainContext
sourcepub fn channel<T>(priority: Priority) -> (Sender<T>, Receiver<T>)
pub fn channel<T>(priority: Priority) -> (Sender<T>, Receiver<T>)
Creates a channel for a main context.
The Receiver has to be attached to a main context at a later time, together with a
closure that will be called for every item sent to a Sender.
The Sender can be cloned and both the Sender and Receiver can be sent to different
threads as long as the item type implements the Send trait.
When the last Sender is dropped the channel is removed from the main context. If the
Receiver is dropped and not attached to a main context all sending to the Sender
will fail.
The returned Sender behaves the same as std::sync::mpsc::Sender.
sourcepub fn sync_channel<T>(
priority: Priority,
bound: usize
) -> (SyncSender<T>, Receiver<T>)
pub fn sync_channel<T>(
priority: Priority,
bound: usize
) -> (SyncSender<T>, Receiver<T>)
Creates a synchronous channel for a main context with a given bound on the capacity of the channel.
The Receiver has to be attached to a main context at a later time, together with a
closure that will be called for every item sent to a SyncSender.
The SyncSender can be cloned and both the SyncSender and Receiver can be sent to different
threads as long as the item type implements the Send trait.
When the last SyncSender is dropped the channel is removed from the main context. If the
Receiver is dropped and not attached to a main context all sending to the SyncSender
will fail.
The returned SyncSender behaves the same as std::sync::mpsc::SyncSender.