Struct glib::OptionFlags
source · [−]pub struct OptionFlags { /* private fields */ }Implementations
sourceimpl OptionFlags
impl OptionFlags
pub const NONE: OptionFlags = _
pub const HIDDEN: OptionFlags = _
pub const IN_MAIN: OptionFlags = _
pub const REVERSE: OptionFlags = _
pub const NO_ARG: OptionFlags = _
pub const FILENAME: OptionFlags = _
pub const OPTIONAL_ARG: OptionFlags = _
pub const NOALIAS: OptionFlags = _
sourcepub const fn empty() -> OptionFlags
pub const fn empty() -> OptionFlags
Returns an empty set of flags
sourcepub const fn all() -> OptionFlags
pub const fn all() -> OptionFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<OptionFlags>
pub fn from_bits(bits: u32) -> Option<OptionFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> OptionFlags
pub const fn from_bits_truncate(bits: u32) -> OptionFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> OptionFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> OptionFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: OptionFlags) -> bool
pub const fn intersects(&self, other: OptionFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: OptionFlags) -> bool
pub const fn contains(&self, other: OptionFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: OptionFlags)
pub fn insert(&mut self, other: OptionFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: OptionFlags)
pub fn remove(&mut self, other: OptionFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: OptionFlags)
pub fn toggle(&mut self, other: OptionFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: OptionFlags, value: bool)
pub fn set(&mut self, other: OptionFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.