Struct glib::ParamFlags
source · [−]pub struct ParamFlags { /* private fields */ }Implementations
sourceimpl ParamFlags
impl ParamFlags
pub const READABLE: ParamFlags = _
pub const WRITABLE: ParamFlags = _
pub const READWRITE: ParamFlags = _
pub const CONSTRUCT: ParamFlags = _
pub const CONSTRUCT_ONLY: ParamFlags = _
pub const LAX_VALIDATION: ParamFlags = _
pub const STATIC_NAME: ParamFlags = _
pub const PRIVATE: ParamFlags = _
pub const STATIC_NICK: ParamFlags = _
pub const STATIC_BLURB: ParamFlags = _
pub const EXPLICIT_NOTIFY: ParamFlags = _
pub const DEPRECATED: ParamFlags = _
sourcepub const fn empty() -> ParamFlags
pub const fn empty() -> ParamFlags
Returns an empty set of flags
sourcepub const fn all() -> ParamFlags
pub const fn all() -> ParamFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<ParamFlags>
pub fn from_bits(bits: u32) -> Option<ParamFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> ParamFlags
pub const fn from_bits_truncate(bits: u32) -> ParamFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> ParamFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> ParamFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: ParamFlags) -> bool
pub const fn intersects(&self, other: ParamFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: ParamFlags) -> bool
pub const fn contains(&self, other: ParamFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: ParamFlags)
pub fn insert(&mut self, other: ParamFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: ParamFlags)
pub fn remove(&mut self, other: ParamFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: ParamFlags)
pub fn toggle(&mut self, other: ParamFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: ParamFlags, value: bool)
pub fn set(&mut self, other: ParamFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.