Struct glib::SignalFlags
source · [−]pub struct SignalFlags { /* private fields */ }Implementations
sourceimpl SignalFlags
impl SignalFlags
pub const RUN_FIRST: SignalFlags = _
pub const RUN_LAST: SignalFlags = _
pub const RUN_CLEANUP: SignalFlags = _
pub const NO_RECURSE: SignalFlags = _
pub const DETAILED: SignalFlags = _
pub const ACTION: SignalFlags = _
pub const NO_HOOKS: SignalFlags = _
pub const MUST_COLLECT: SignalFlags = _
pub const DEPRECATED: SignalFlags = _
sourcepub const fn empty() -> SignalFlags
pub const fn empty() -> SignalFlags
Returns an empty set of flags
sourcepub const fn all() -> SignalFlags
pub const fn all() -> SignalFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<SignalFlags>
pub fn from_bits(bits: u32) -> Option<SignalFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> SignalFlags
pub const fn from_bits_truncate(bits: u32) -> SignalFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> SignalFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> SignalFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: SignalFlags) -> bool
pub const fn intersects(&self, other: SignalFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: SignalFlags) -> bool
pub const fn contains(&self, other: SignalFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: SignalFlags)
pub fn insert(&mut self, other: SignalFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: SignalFlags)
pub fn remove(&mut self, other: SignalFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: SignalFlags)
pub fn toggle(&mut self, other: SignalFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: SignalFlags, value: bool)
pub fn set(&mut self, other: SignalFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.