pub struct Source { /* private fields */ }Expand description
The GSource struct is an opaque data type
representing an event source.
GLib type: Shared boxed type with reference counted clone semantics.
Implementations
Sourceimpl Source
impl Source
Sourcepub fn add_child_source(&self, child_source: &Source)
pub fn add_child_source(&self, child_source: &Source)
t need @child_source to do anything on its own when it
triggers, you can call g_source_set_dummy_callback() on it to set a
callback that does nothing (except return true if appropriate).
The @self will hold a reference on @child_source while @child_source is attached to it.
This API is only intended to be used by implementations of Source.
Do not call this API on a Source that you did not create.
child_source
poll
pub fn destroy(&self)
Sourcepub fn can_recurse(&self) -> bool
pub fn can_recurse(&self) -> bool
Checks whether a source is allowed to be called recursively.
See GLib::Source::set_can_recurse().
Returns
whether recursion is allowed
Sourcepub fn name(&self) -> Option<GString>
pub fn name(&self) -> Option<GString>
Gets a name for the source, used in debugging and profiling.
The
name may be NULL if it has never been set with GLib::Source::set_name().
Returns
the name of the source
Sourcepub fn ready_time(&self) -> i64
pub fn ready_time(&self) -> i64
of @self, as set by
GLib::Source::set_ready_time().
Any time before or equal to the current monotonic time (including zero) is an indication that the source will fire immediately.
Returns
never
Sourcepub fn time(&self) -> i64
pub fn time(&self) -> i64
Gets the time to be used when checking this source.
The advantage of
calling this function over calling monotonic_time() directly is
that when checking multiple sources, GLib can cache a single value
instead of having to repeatedly get the system monotonic time.
The time here is the system monotonic time, if available, or some
other reasonable alternative otherwise. See monotonic_time().
Returns
the monotonic time in microseconds
Sourcepub fn is_destroyed(&self) -> bool
pub fn is_destroyed(&self) -> bool
idle_id_mutex);
return FALSE; }
Calls to this function from a thread other than the one acquired by the
[`MainContext`][crate::MainContext] the [`Source`][crate::Source] is attached to are typically
redundant, as the source could be destroyed immediately after this function
returns. However, once a source is destroyed it cannot be un-destroyed, so
this function can be used for opportunistic checks from any thread.
# Returns
true if the source has been destroyed, false otherwiseSourcepub fn remove_child_source(&self, child_source: &Source)
pub fn remove_child_source(&self, child_source: &Source)
Detaches @child_source from @self and destroys it.
This API is only intended to be used by implementations of Source.
Do not call this API on a Source that you did not create.
child_source
a source previously passed to
add_child_source()
Sourceimpl Source
impl Source
pub fn attach(&self, context: Option<&MainContext>) -> SourceId
Sourcepub fn context(&self) -> Option<MainContext>
pub fn context(&self) -> Option<MainContext>
Gets the MainContext with which the source is associated.
You can call this on a source that has been destroyed, provided
that the MainContext it was attached to still exists (in which
case it will return that MainContext). In particular, you can
always call this function on the source returned from
main_current_source(). But calling this function on a source
whose MainContext has been destroyed is an error.
If the associated MainContext could be destroy concurrently from
a different thread, then this function is not safe to call and
[dup_context()][Self::dup_context()] should be used instead.
Returns
the main context with which the
source is associated, or NULL if the context has not yet been added to a
source