Struct glib::SpawnFlags
source · [−]pub struct SpawnFlags { /* private fields */ }Implementations
sourceimpl SpawnFlags
impl SpawnFlags
pub const DEFAULT: SpawnFlags = _
pub const LEAVE_DESCRIPTORS_OPEN: SpawnFlags = _
pub const DO_NOT_REAP_CHILD: SpawnFlags = _
pub const SEARCH_PATH: SpawnFlags = _
pub const STDOUT_TO_DEV_NULL: SpawnFlags = _
pub const STDERR_TO_DEV_NULL: SpawnFlags = _
pub const CHILD_INHERITS_STDIN: SpawnFlags = _
pub const FILE_AND_ARGV_ZERO: SpawnFlags = _
pub const SEARCH_PATH_FROM_ENVP: SpawnFlags = _
pub const CLOEXEC_PIPES: SpawnFlags = _
sourcepub const fn empty() -> SpawnFlags
pub const fn empty() -> SpawnFlags
Returns an empty set of flags
sourcepub const fn all() -> SpawnFlags
pub const fn all() -> SpawnFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<SpawnFlags>
pub fn from_bits(bits: u32) -> Option<SpawnFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> SpawnFlags
pub const fn from_bits_truncate(bits: u32) -> SpawnFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> SpawnFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> SpawnFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: SpawnFlags) -> bool
pub const fn intersects(&self, other: SpawnFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: SpawnFlags) -> bool
pub const fn contains(&self, other: SpawnFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: SpawnFlags)
pub fn insert(&mut self, other: SpawnFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: SpawnFlags)
pub fn remove(&mut self, other: SpawnFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: SpawnFlags)
pub fn toggle(&mut self, other: SpawnFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: SpawnFlags, value: bool)
pub fn set(&mut self, other: SpawnFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.