pub struct UriFlags(/* private fields */);v2_66 only.Expand description
Flags that describe a URI.
When parsing a URI, if you need to choose different flags based on the type of URI, you can use g_uri_peek_scheme() on the URI string to check the scheme first, and use that to decide what flags to parse it with.
Implementations
Sourceimpl UriFlags
impl UriFlags
Sourcepub const PARSE_RELAXED: Self
pub const PARSE_RELAXED: Self
t use this flag unless you need to.
Sourcepub const HAS_PASSWORD: Self
pub const HAS_PASSWORD: Self
The userinfo field may contain a password,
which will be separated from the username by :.
Sourcepub const HAS_AUTH_PARAMS: Self
pub const HAS_AUTH_PARAMS: Self
The userinfo may contain additional
authentication-related parameters, which will be separated from
the username and/or password by ;.
Sourcepub const ENCODED: Self
pub const ENCODED: Self
When parsing a URI, this indicates that %-encoded
characters in the userinfo, path, query, and fragment fields
should not be decoded. (And likewise the host field if
NON_DNS is also set.) When building a URI, it indicates
that you have already %-encoded the components, and so #GUri
should not do any encoding itself.
Sourcepub const NON_DNS: Self
pub const NON_DNS: Self
The host component should not be assumed to be a
DNS hostname or IP address (for example, for smb URIs with NetBIOS
hostnames).
Sourcepub const ENCODED_QUERY: Self
pub const ENCODED_QUERY: Self
Same as ENCODED, for the query
field only.
Sourcepub const ENCODED_PATH: Self
pub const ENCODED_PATH: Self
Same as ENCODED, for the path only.
Sourcepub const ENCODED_FRAGMENT: Self
pub const ENCODED_FRAGMENT: Self
Same as ENCODED, for the
fragment only.
Sourcepub const SCHEME_NORMALIZE: Self
pub const SCHEME_NORMALIZE: Self
A scheme-based normalization will be applied.
For example, when parsing an HTTP URI changing omitted path to / and
omitted port to 80; and when building a URI, changing empty path to /
and default port 80). This only supports a subset of known schemes. (Since: 2.68)
Sourceimpl UriFlags
impl UriFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl UriFlags
impl UriFlags
Sourcepub const fn iter(&self) -> Iter<UriFlags>
pub const fn iter(&self) -> Iter<UriFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<UriFlags>
pub const fn iter_names(&self) -> IterNames<UriFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.