pub struct Borrowed<T>(/* private fields */);Expand description
Wrapper around values representing borrowed C memory.
This is returned by from_glib_borrow() and ensures that the wrapped value
is never dropped when going out of scope.
Borrowed values must never be passed by value or mutable reference to safe Rust code and must not leave the C scope in which they are valid.
Implementations