pub fn format_size(size: u64) -> GStringExpand description
t separated when line wrapped.
The prefix units base is 1000 (i.e. 1 kB is 1000 bytes).
This string should be freed with g_free() when not needed any longer.
See g_format_size_full() for more options about how the size might be formatted.
size
a size in bytes
Returns
a newly-allocated formatted string containing a human readable file size