main_depth

Function main_depth 

pub fn main_depth() -> i32
t handle arbitrary callbacks. Instead, structure your code so that you simply return to the main loop and then get called again when there is more work to do.

Returns

the main loop recursion level in the current thread