pub trait TypePluginExt: IsA<TypePlugin> + 'static {
// Provided methods
fn complete_interface_info(
&self,
instance_type: Type,
interface_type: Type,
) -> InterfaceInfo { ... }
fn complete_type_info(&self, g_type: Type) -> (TypeInfo, TypeValueTable) { ... }
fn unuse(&self) { ... }
fn use_(&self) { ... }
}Expand description
Provided Methods
Sourcefn complete_interface_info(
&self,
instance_type: Type,
interface_type: Type,
) -> InterfaceInfo
fn complete_interface_info( &self, instance_type: Type, interface_type: Type, ) -> InterfaceInfo
Calls the @complete_interface_info function from the #GTypePluginClass of @self. There should be no need to use this function outside of the GObject type system itself.
instance_type
the #GType of an instantiatable type to which the interface is added
interface_type
the #GType of the interface whose info is completed
info
the #GInterfaceInfo to fill in
Sourcefn complete_type_info(&self, g_type: Type) -> (TypeInfo, TypeValueTable)
fn complete_type_info(&self, g_type: Type) -> (TypeInfo, TypeValueTable)
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.