pub trait Property {
type Value: HasParamSpec;
}Expand description
A type that can be used as a property. It covers every type which have an associated ParamSpec
(HasParamSpec) and some useful types wrapping HasParamSpec.
The definition is recursive, so you can nest many Propertys together. The final ParamSpec will
be the one of the innermost type
Required Associated Types
type Value: HasParamSpec
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".