pub struct VariantTy { /* private fields */ }Expand description
Describes Variant types.
This is a borrowed counterpart of VariantType.
Essentially it’s a str statically guaranteed to be a valid type string.
Implementations
sourceimpl VariantTy
impl VariantTy
sourcepub fn new(type_string: &str) -> Result<&VariantTy, ()>
pub fn new(type_string: &str) -> Result<&VariantTy, ()>
Tries to create a &VariantTy from a string slice.
Returns Ok if the string is a valid type string, Err otherwise.
sourcepub unsafe fn from_str_unchecked(type_string: &str) -> &VariantTy
pub unsafe fn from_str_unchecked(type_string: &str) -> &VariantTy
Converts a type string into &VariantTy without any checks.