pub struct VariantTy { /* private fields */ }
Describes Variant types.

This is a borrowed counterpart of VariantType. Essentially it’s a str statically guaranteed to be a valid type string.

Implementations

Tries to create a &VariantTy from a string slice.

Returns Ok if the string is a valid type string, Err otherwise.

Converts a type string into &VariantTy without any checks.

Converts to a string slice.