[−][src]Struct glib::value::SendValue
A version of Value for storing Send types, that implements Send
itself.
See the module documentation for more details.
Methods
impl SendValue[src]
pub fn downcast<'a, T: FromValueOptional<'a> + SetValue + Send>(
self
) -> Result<TypedValue<T>, Self>[src]
self
) -> Result<TypedValue<T>, Self>
Tries to downcast to a TypedValue.
Returns Ok(TypedValue<T>) if the value carries a type corresponding
to T and Err(self) otherwise.
pub fn downcast_ref<'a, T: FromValueOptional<'a> + SetValue>(
&self
) -> Option<&TypedValue<T>>[src]
&self
) -> Option<&TypedValue<T>>
Tries to downcast to a &TypedValue.
Returns Some(&TypedValue<T>) if the value carries a type corresponding
to T and None otherwise.
Methods from Deref<Target = Value>
pub fn downcast_ref<'a, T: FromValueOptional<'a> + SetValue>(
&self
) -> Option<&TypedValue<T>>[src]
&self
) -> Option<&TypedValue<T>>
Tries to downcast to a &TypedValue.
Returns Some(&TypedValue<T>) if the value carries a type corresponding
to T and None otherwise.
pub fn get<'a, T: FromValueOptional<'a>>(&'a self) -> Option<T>[src]
Tries to get a value of type T.
Returns Some if the type is correct and the value is not None.
This function doesn't distinguish between type mismatches and correctly
typed None values. Use downcast or is for that.
pub fn is<'a, T: FromValueOptional<'a> + SetValue>(&self) -> bool[src]
Returns true if the type of the value corresponds to T
or is a sub-type of T.
pub fn type_(&self) -> Type[src]
Returns the type of the value.